@@ -26,7 +26,7 @@ use strict;
 use warnings;
 use autodie;
 
-use Lintian::Info::Changelog::Version;
+use Lintian::Inspect::Changelog::Version;
 use Lintian::Util qw($PKGREPACK_REGEX);
 
 use constant EMPTY => q{};
@@ -42,30 +42,32 @@ our $SIGNING_KEY_FILENAMES= Lintian::Data->new('common/signing-key-filenames');
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     my $template = 0;
     my $withgpgverification = 0;
-    my $wfile = $info->index_resolved_path('debian/watch');
-    my ($watchver, %dversions);
+    my $wfile = $processable->index_resolved_path('debian/watch');
+    my ($standard, %dversions);
 
     if (not $wfile or not $wfile->is_open_ok) {
-        $self->tag('debian-watch-file-is-missing') unless ($info->native);
+        $self->tag('debian-watch-file-is-missing')
+          unless ($processable->native);
         return;
     }
 
     # Perform the other checks even if it is a native package
-    $self->tag('debian-watch-file-in-native-package') if ($info->native);
+    $self->tag('debian-watch-file-in-native-package')
+      if ($processable->native);
 
     # Check if the Debian version contains anything that resembles a repackaged
     # source package sign, for fine grained version mangling check
     # If the version field is missing, we assume a neutral non-native one.
 
     # upstream method returns empty for native packages
-    my $upstream = $info->version->upstream;
+    my $upstream = $processable->changelog_version->upstream;
     my ($prerelease) = ($upstream =~ qr/(alpha|beta|rc)/i);
 
-    # there is a good repack indicator in $info->repacked but we need the text
+# there is a good repack indicator in $processable->repacked but we need the text
     my ($repack) = ($upstream =~ $PKGREPACK_REGEX);
 
     # Gather information from the watch file and look for problems we can
@@ -90,23 +92,25 @@ sub source {
         }
 
         if (/^version\s*=\s*(\d+)(?:\s|\Z)/) {
-            if (defined $watchver) {
-                $self->tag('debian-watch-file-declares-multiple-versions',
-                    "line $.");
-            }
-            $watchver = $1;
+            $self->tag('debian-watch-file-declares-multiple-versions',
+                "line $.")
+              if defined $standard;
+
+            $standard = $1;
+
             my $minver = $WATCH_VERSION->value('min-version');
             my $maxver = $WATCH_VERSION->value('max-version');
-            if ($watchver < $minver or $watchver > $maxver) {
-                $self->tag('debian-watch-file-unknown-version', $watchver);
-            }
+            $self->tag('debian-watch-file-unknown-version', $standard)
+              if $standard < $minver || $standard > $maxver;
+
         } else {
-            unless (defined($watchver)) {
+            unless (defined $standard) {
                 $self->tag('debian-watch-file-missing-version');
-                $watchver = 1;
+                $standard = 1;
             }
+
             # Version 1 watch files are too broken to try checking them.
-            next if ($watchver == 1);
+            next if $standard == 1;
 
             my (
                 $repack_mangle, $repack_dmangle,
@@ -117,7 +121,7 @@ sub source {
             if (   s/^opt(?:ion)?s=\"((?:[^\"]|\\\")+)\"\s+//
                 || s/^opt(?:ion)?s=(\S+)\s+//) {
                 $opts = $1;
-                @opts = split($watchver >= 4 ? '\s*,\s*' : ',', $opts);
+                @opts = split($standard >= 4 ? '\s*,\s*' : ',', $opts);
                 for (@opts) {
                     $repack_mangle = 1
                       if defined $repack
@@ -132,7 +136,7 @@ sub source {
                       if defined $prerelease
                       and /^uversionmangle\s*=.*$prerelease/;
                     $repack_dmangle_auto = 1
-                      if $watchver >= 4
+                      if $standard >= 4
                       and /^dversionmangle\s*=.*(?:s\/\@DEB_EXT\@\/|auto)/;
                     $withgpgverification = 1
                       if /^pgpsigurlmangle\s*=\s*/;
@@ -207,6 +211,8 @@ sub source {
     }
     close($fd);
 
+    $self->tag('debian-watch-file-standard', $standard);
+
     $self->tag('debian-watch-contains-dh_make-template', "(line $template)")
       if $template;
     $self->tag('debian-watch-does-not-check-gpg-signature')
@@ -215,7 +221,7 @@ sub source {
     # Look for upstream signing key
     my $key_found = 0;
     for my $key_name ($SIGNING_KEY_FILENAMES->all) {
-        my $path = $info->index_resolved_path("debian/$key_name");
+        my $path = $processable->index_resolved_path("debian/$key_name");
         if ($path and $path->is_file) {
             $key_found = $path;
             last;
@@ -232,11 +238,11 @@ sub source {
           if $key_found;
     }
 
-    if (defined $info->changelog
+    if (defined $processable->changelog
         && %dversions) {
         my %changelog_versions;
         my $count = 1;
-        for my $entry (@{$info->changelog->entries}) {
+        for my $entry (@{$processable->changelog->entries}) {
             my $uversion = $entry->Version;
             $uversion =~ s/-[^-]+$//; # revision
             $uversion =~ s/^\d+://; # epoch
@@ -251,7 +257,7 @@ sub source {
         while (my ($dversion, $lines) = each %dversions) {
             next if (!defined($dversion) || $dversion eq 'debian');
             local $" = ', ';
-            if (!$info->native
+            if (!$processable->native
                 && exists($changelog_versions{'orig'}{$dversion})) {
                 $self->tag(
                     'debian-watch-file-specifies-wrong-upstream-version',
