@@ -29,15 +29,16 @@ use warnings;
 use autodie;
 
 use List::MoreUtils qw(any);
-use Moo;
 
 use Lintian::Data ();
-use Lintian::Tags qw(tag);
-
-with('Lintian::Check');
 
 use constant EMPTY => q{};
 
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
 our $KNOWN_VCS_HOSTERS= Lintian::Data->new(
     'fields/vcs-hosters',
     qr/\s*~~\s*/,
@@ -165,19 +166,30 @@ sub always {
     my ($self) = @_;
 
     my $type = $self->type;
-    my $info = $self->info;
+    my $processable = $self->processable;
 
+    # team-maintained = maintainer or uploaders field contains a mailing list
+    my $is_teammaintained = 0;
+    my $team_email = '';
+    # co-maintained = maintained by an informal group of people,
+    # i. e. >= 1 uploader and not team-maintained
     my $is_comaintained = 0;
+    my $is_maintained_by_individual = 1;
+    my $num_uploaders = 0;
     for my $field (qw(maintainer uploaders)) {
 
-        my $maintainer = $info->unfolded_field($field);
+        my $maintainer = $processable->unfolded_field($field);
 
         next
           unless defined $maintainer;
 
-        my $is_list = $maintainer =~ /\@lists(?:\.alioth)?\.debian\.org\b/;
-        $is_comaintained = 1
-          if $is_list;
+        my $is_list
+          = $maintainer =~ /\b(\S+\@lists(?:\.alioth)?\.debian\.org)\b/;
+        if ($is_list) {
+            $is_teammaintained = 1;
+            $team_email = $1;
+            $is_maintained_by_individual = 0;
+        }
 
         if ($field eq 'uploaders') {
 
@@ -188,40 +200,54 @@ sub always {
             my @uploaders = map { split /\@\S+\K\s*,\s*/ }
               split />\K\s*,\s*/, $maintainer;
 
-            $is_comaintained = 1
-              if @uploaders;
+            $num_uploaders = scalar @uploaders;
+
+            if (@uploaders) {
+                $is_comaintained = 1
+                  unless $is_teammaintained;
+                $is_maintained_by_individual = 0;
+            }
+
         }
     }
 
+    $self->tag('package-is-team-maintained', $team_email, $num_uploaders)
+      if $is_teammaintained;
+    $self->tag('package-is-co-maintained', $num_uploaders)
+      if $is_comaintained;
+    $self->tag('package-is-maintained-by-individual')
+      if $is_maintained_by_individual;
+
     my %seen_vcs;
     while (my ($platform, $splitter) = each %VCS_EXTRACT) {
 
         my $fieldname = "vcs-$platform";
-
-        my $uri = $info->unfolded_field($fieldname);
+        my $maintainer = $processable->field('maintainer', EMPTY);
+        my $uri = $processable->unfolded_field($fieldname);
 
         next
           unless defined $uri;
 
         my @parts = &$splitter($uri);
         if (not @parts or not $parts[0]) {
-            tag 'vcs-field-uses-unknown-uri-format', $fieldname, $uri;
+            $self->tag('vcs-field-uses-unknown-uri-format', $fieldname, $uri);
         } else {
             if (    $VCS_RECOMMENDED_URIS{$platform}
                 and $parts[0] !~ $VCS_RECOMMENDED_URIS{$platform}) {
                 if (    $VCS_VALID_URIS{$platform}
                     and $parts[0] =~ $VCS_VALID_URIS{$platform}) {
-                    tag 'vcs-field-uses-not-recommended-uri-format',
-                      $fieldname, $uri;
+                    $self->tag('vcs-field-uses-not-recommended-uri-format',
+                        $fieldname, $uri);
                 } else {
-                    tag 'vcs-field-uses-unknown-uri-format', $fieldname,$uri;
+                    $self->tag('vcs-field-uses-unknown-uri-format',
+                        $fieldname,$uri);
                 }
             }
 
-            tag 'vcs-field-has-unexpected-spaces', $fieldname, $uri
+            $self->tag('vcs-field-has-unexpected-spaces', $fieldname, $uri)
               if (any { $_ and /\s/} @parts);
 
-            tag 'vcs-field-uses-insecure-uri', $fieldname, $uri
+            $self->tag('vcs-field-uses-insecure-uri', $fieldname, $uri)
               if $parts[0] =~ m%^(?:git|(?:nosmart\+)?http|svn)://%
               || $parts[0] =~ m%^(?:lp|:pserver):%;
         }
@@ -235,18 +261,18 @@ sub always {
                 &$canonify($canonicalized, $tag);
             }
 
-            tag $tag, $parts[0], $canonicalized
+            $self->tag($tag, $parts[0], $canonicalized)
               unless $canonicalized eq $parts[0];
         }
 
         if ($platform eq 'browser') {
 
-            tag 'vcs-browser-links-to-empty-view', $uri
+            $self->tag('vcs-browser-links-to-empty-view', $uri)
               if $uri =~ m%rev=0&sc=0%;
 
         } else {
-            tag 'vcs', $platform;
-            tag 'vcs-uri', $uri;
+            $self->tag('vcs', $platform);
+            $self->tag('vcs-uri', $uri);
             $seen_vcs{$platform}++;
 
             foreach my $regex ($KNOWN_VCS_HOSTERS->all) {
@@ -256,9 +282,8 @@ sub always {
                         && $platform ne $re_vcs
                         && $platform ne 'browser') {
 
-                        tag 'vcs-field-mismatch',
-                          "vcs-$platform != vcs-$re_vcs",
-                          $uri;
+                        $self->tag('vcs-field-mismatch',
+                            "vcs-$platform != vcs-$re_vcs",$uri);
 
                         # warn once
                         last;
@@ -268,35 +293,45 @@ sub always {
         }
 
         if ($uri =~ m{//(.+)\.debian\.org/}) {
-            tag 'vcs-obsolete-in-debian-infrastructure', $fieldname, $uri
+            $self->tag('vcs-obsolete-in-debian-infrastructure',
+                $fieldname, $uri)
               unless $1 =~ m{^(?:salsa|.*\.dgit)$};
 
         } else {
-            tag 'orphaned-package-not-maintained-in-debian-infrastructure',
-              $fieldname, $uri
-              if $info->field('maintainer', EMPTY)=~ /packages\@qa.debian.org/
+            $self->tag(
+                'orphaned-package-not-maintained-in-debian-infrastructure',
+                $fieldname, $uri)
+              if $maintainer =~ /packages\@qa.debian.org/
               && $platform ne 'browser';
         }
+
+        $self->tag('wrong-vcs-location-for-dpmt')
+          if $maintainer =~ m{python-modules-team\@lists\.alioth\.debian\.org}
+          and $uri !~ m{salsa.debian.org/python-team/modules/.+};
+
+        $self->tag('wrong-vcs-location-for-papt')
+          if $maintainer =~ m{python-apps-team\@lists\.alioth\.debian\.org}
+          and $uri !~ m{salsa.debian.org/python-team/applications/.+};
     }
 
-    tag 'vcs-fields-use-more-than-one-vcs', sort keys %seen_vcs
+    $self->tag('vcs-fields-use-more-than-one-vcs', sort keys %seen_vcs)
       if keys %seen_vcs > 1;
 
-    tag 'co-maintained-package-with-no-vcs-fields'
+    $self->tag('co-maintained-package-with-no-vcs-fields')
       if $type eq 'source'
-      and $is_comaintained
+      and ($is_comaintained or $is_teammaintained)
       and not %seen_vcs;
 
     # Check for missing Vcs-Browser headers
-    unless (defined $info->field('vcs-browser')) {
+    unless (defined $processable->field('vcs-browser')) {
 
         foreach my $regex ($KNOWN_VCS_HOSTERS->all) {
 
             my $platform = @{$KNOWN_VCS_HOSTERS->value($regex)}[0];
             my $fieldname = "vcs-$platform";
 
-            if ($info->field($fieldname, EMPTY) =~ m/^($regex.*)/xi) {
-                tag 'missing-vcs-browser-field', $fieldname, $1;
+            if ($processable->field($fieldname, EMPTY) =~ m/^($regex.*)/xi) {
+                $self->tag('missing-vcs-browser-field', $fieldname, $1);
 
                 # warn once
                 last;
