@@ -70,12 +70,12 @@ sub files {
 
         # check if it's the "perl" package itself
         $self->tag('perl-module-in-core-directory', $file)
-          unless $self->processable->pkg_src eq 'perl';
+          unless $self->processable->source eq 'perl';
     }
 
     # perl modules using old libraries
     # we do the same check on perl scripts in checks/scripts
-    my $dep = $self->info->relation('strong');
+    my $dep = $self->processable->relation('strong');
     if (   $file->is_file
         && $file->name =~ m,\.pm$,
         && !$dep->implies('libperl4-corelibs-perl | perl (<< 5.12.3-7)')) {
