@@ -25,10 +25,11 @@ use warnings;
 use autodie;
 
 use Moo;
+use namespace::clean;
 
 use Lintian::Data;
 
-with('Lintian::Check');
+with 'Lintian::Check';
 
 my $ALLOWED_PYTHON_FILES = Lintian::Data->new('files/allowed-python-files');
 my $GENERIC_PYTHON_MODULES= Lintian::Data->new('files/generic-python-modules');
@@ -71,8 +72,8 @@ sub files {
         && $file->name !~ m,^usr/lib/python\d\.\d/(?:site|dist)-packages/,){
 
         $self->tag('third-party-package-in-python-dir', $file->name)
-          unless $self->processable->pkg_src =~ m/^python(?:\d\.\d)?$/
-          || $self->processable->pkg_src =~ m{\A python\d?-
+          unless $self->processable->source =~ m/^python(?:\d\.\d)?$/
+          || $self->processable->source =~ m{\A python\d?-
                                (?:stdlib-extensions|profiler|old-doctools) \Z}xsm;
     }
 
